Structs
- Arithmetic
Parser - The
ArithmeticParseris a parser generated bypestbased on the grammar defined ingrammar.pest.
Enums
- Parse
Error - The
ParseErrorenum represents errors that can occur during the parsing of arithmetic expressions. - Rule
Functions
- parse_
expression - Parses an arithmetic expression and prints its parse tree.